package com.example.educode.controller.activity;

import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.view.inputmethod.InputMethodManager;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import androidx.appcompat.app.AppCompatActivity;

import com.example.educode.R;
import com.example.educode.data.DBFacade;
import com.google.firebase.auth.FirebaseAuth;


public class CreateAccountActivity extends AppCompatActivity {


    private Button createButton;
    private EditText text_name;
    private EditText text_email;
    private EditText text_password;
    private DBFacade dbFacade = new DBFacade(this);
    private Button backButton;

    private FirebaseAuth mAuth;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_createaccount);

        mAuth = FirebaseAuth.getInstance();

        text_email = findViewById(R.id.editText_email1);
        text_password = findViewById(R.id.editText_password1);
        text_name = findViewById(R.id.editText_name);
        createButton = findViewById(R.id.button_createAccount);
        backButton = findViewById(R.id.button_backCertificate2);
        backButton.setBackgroundResource(R.drawable.back);

        createButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                createUser();
            }

        });

        backButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                backToLoginActivity();
            }
        });

    }

    /**
     * Method to create a user in Firebase and SqLite
     */
    public void createUser(){
        String name = text_name.getText().toString();
        String email = text_email.getText().toString();
        String password = text_password.getText().toString();
        if(!email.isEmpty() && !password.isEmpty() && !name.isEmpty()){
            mAuth.createUserWithEmailAndPassword(email, password)
                    .addOnCompleteListener(this, task -> {
                        if (task.isSuccessful()) {
                            createLocalUser();
                            createFireStoreUser();
                            startFormation();
                        } else {
                            if(password.length() < 6){
                                Toast.makeText(this, "La contraseña debe de tener más de 5 caracteres",
                                        Toast.LENGTH_SHORT).show();
                            }else{
                                Toast.makeText(this, "Correo no válido",
                                        Toast.LENGTH_SHORT).show();
                            }

                        }
                    });
        }else{
            if(name.isEmpty()){
                Toast.makeText(this, "Debes escribir un nombre", Toast.LENGTH_SHORT).show();
                text_name.requestFocus();
                InputMethodManager imm = (InputMethodManager) getSystemService(this.INPUT_METHOD_SERVICE);
                imm.showSoftInput(text_name, InputMethodManager.SHOW_IMPLICIT);
            }else if(email.isEmpty()){
                Toast.makeText(this, "Debes escribir una dirección de correo", Toast.LENGTH_SHORT).show();
                text_email.requestFocus();
                InputMethodManager imm = (InputMethodManager) getSystemService(this.INPUT_METHOD_SERVICE);
                imm.showSoftInput(text_email, InputMethodManager.SHOW_IMPLICIT);
            }else if(password.isEmpty()){
                Toast.makeText(this, "Debes escribir una contraseña", Toast.LENGTH_SHORT).show();
                text_password.requestFocus();
                InputMethodManager imm = (InputMethodManager) getSystemService(this.INPUT_METHOD_SERVICE);
                imm.showSoftInput(text_password, InputMethodManager.SHOW_IMPLICIT);
            }
        }
    }

    /**
     * Method to create a new local account
     */
    public void createLocalUser(){
        dbFacade.createPlayer(text_name.getText().toString(), text_email.getText().toString());
        dbFacade.insertAllQuestionsToDB();
    }

    /**
     * Method to create a new firebase account
     */
    public void createFireStoreUser(){
        dbFacade.createFireStorePlayer(text_name.getText().toString(), text_email.getText().toString());
    }

    /**
     * Method to start the formation activity
     */
    public void startFormation(){
        Intent intent = new Intent(this, FormationActivity.class);
        finish();
        startActivity(intent);
    }

    /**
     * Method to back the login activity
     */
    public void backToLoginActivity(){
        Intent intent = new Intent(this, LoginActivity.class);
        finish();
        startActivity(intent);
    }

    @Override
    protected void onPause() {
        super.onPause();
        //stopService(new Intent(CreateAccountActivity.this,BackgroundSoundService.class));
    }

    @Override
    protected void onResume() {
        super.onResume();
        //startService(new Intent(CreateAccountActivity.this,BackgroundSoundService.class));
    }




}
