package com.example.educode.controller.activity;

import androidx.appcompat.app.AlertDialog;
import androidx.appcompat.app.AppCompatActivity;
import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentManager;
import androidx.fragment.app.FragmentTransaction;


import android.content.ContentValues;
import android.content.DialogInterface;
import android.content.Intent;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.os.Bundle;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;
import android.widget.Toast;

import com.example.educode.data.AdminSQLiteOpenHelper;
import com.example.educode.data.DBFacade;
import com.example.educode.R;
import com.example.educode.controller.fragment.AvatarFragment;
import com.example.educode.controller.fragment.FormationFragment;

public class FormationActivity extends AppCompatActivity {

    private Fragment fragmentFormation;
    private FragmentTransaction transaction;
    private Fragment fragmentAvatar;
    private Button continueButton;
    private SQLiteDatabase db;
    private String name;
    private TextView tetview_welcome;
    private int numString = 0;
    private DBFacade dbFacade = new DBFacade(this);
    private String[] strings = new String[]{
            "Escoge un avatar ",
            "Hola "
    };

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_formation);
        fragmentAvatar = new AvatarFragment();
        getSupportFragmentManager().beginTransaction().add(R.id.fragmentContainer, fragmentAvatar).commit();
        tetview_welcome = findViewById(R.id.textView_welcome);
        name = dbFacade.getPlayerStringValue(1);
        tetview_welcome.setText(strings[numString] + name);
        continueButton = findViewById(R.id.button_continue);
        continueButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                nextQuestionToFragment();
            }

        });

    }

    /**
     * Method to change the fragment container
     */
    public void nextQuestionToFragment(){
        FragmentManager fm = getSupportFragmentManager();
        FormationFragment fragment = (FormationFragment)fm.findFragmentById(R.id.fragmentContainer);
        fragment.nextQuestion();
    }

    /**
     * Method to start the main Activity
     */
    public void finishFormation(){
        Intent intent = new Intent(this, MainMenuActivity.class);

        dbFacade.updatePlayerValue("formacion", 1);

        finish();
        startActivity(intent);
    }

    /**
     * Method to get a instance of SqLite conenction
     * @return Instance of SqLite connection
     */
    public SQLiteDatabase getDbConection(){
        AdminSQLiteOpenHelper admin = new AdminSQLiteOpenHelper(this, "db", null, 1);
        SQLiteDatabase db = admin.getWritableDatabase();
        return db;
    }

    /**
     * Method to save in BD the avatar selected by user
     * @param image Avatar image
     */
    public void setAvatarImage(String image){
        db = getDbConection();

        ContentValues values = new ContentValues();
        values.put("avatar", image);
        db.update("jugador", values,null, null);
        db.close();
    }

    /**
     * Method to get the String of avatar Image
     * @return
     */
    public String getAvatarString(){
        db = getDbConection();
        String imageSrc = "";
        Cursor consulta = db.rawQuery("select * from jugador where id = 1", null);

        if (consulta.moveToFirst()){
            imageSrc = consulta.getString(5);
        }
        db.close();
        return imageSrc;
    }


    /**
     * Method to get the formation fragment and push one
     */
    public void getFormationFragment(){
        numString++;
        tetview_welcome.setText(strings[numString] + name);
        fragmentFormation = new FormationFragment();
        transaction = getSupportFragmentManager().beginTransaction();
        transaction.replace(R.id.fragmentContainer, fragmentFormation).commit();
    }

    /**
     * Method to get a Toast if avatar is not selected
     */
    public void getImageToast(){
        Toast.makeText(this, "Debes elegir un avatar", Toast.LENGTH_SHORT).show();
    }

    /**
     * Method to hide de continue button
     */
    public void setHideButton(){
        continueButton.setVisibility(View.GONE);
    }

    /**
     * Method to make visible de continue button
     */
    public void setVisibleButton(){
        continueButton.setVisibility(View.VISIBLE);
    }

    /**
     * Method to skip the formation
     */
    public void skipFormationDecision(){
        DialogInterface.OnClickListener dialogClickListener = new DialogInterface.OnClickListener() {
            @Override
            public void onClick(DialogInterface dialog, int which) {
                switch (which){
                    case DialogInterface.BUTTON_POSITIVE:
                        finishFormation();
                        break;

                    case DialogInterface.BUTTON_NEGATIVE:
                        break;
                }
            }
        };

        AlertDialog.Builder builder = new AlertDialog.Builder(this);

        builder.setMessage("¿Quieres omitir la formación?").setPositiveButton("Si", dialogClickListener)
                .setNegativeButton("No", dialogClickListener).show();
    }

    @Override
    protected void onPause() {
        super.onPause();
        //stopService(new Intent(FormationActivity.this,BackgroundSoundService.class));
    }

    @Override
    protected void onResume() {
        super.onResume();
        //startService(new Intent(FormationActivity.this,BackgroundSoundService.class));
    }


}
