package com.example.educode.controller.activity;

import androidx.annotation.NonNull;
import androidx.appcompat.app.AppCompatActivity;

import android.app.ProgressDialog;
import android.content.Intent;
import android.os.Bundle;
import android.os.Handler;
import android.view.View;
import android.view.inputmethod.InputMethodManager;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ImageView;
import android.widget.Toast;

import com.example.educode.data.DBFacade;
import com.example.educode.R;
import com.google.android.gms.tasks.OnCompleteListener;
import com.google.android.gms.tasks.Task;
import com.google.firebase.auth.FirebaseAuth;


public class LoginActivity extends AppCompatActivity {

    private Button loginButton;
    private Button createButton;
    private Button resetPasswordButton;
    private EditText text_email;
    private EditText text_password;
    private ImageView startImage;
    private DBFacade dbFacade = new DBFacade(this);
    private FirebaseAuth mAuth;
    private ProgressDialog mDialog;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_login_firebase);

        mAuth = FirebaseAuth.getInstance();
        mDialog = new ProgressDialog(this);

        text_email = findViewById(R.id.editText_name);
        text_password = findViewById(R.id.editText_password);
        startImage = findViewById(R.id.imageView_start);
        loginButton = findViewById(R.id.button_createAccount);
        createButton = findViewById(R.id.button_create);
        resetPasswordButton = findViewById(R.id.button_resetpassword);

        createButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                startCreateAccountActivity();
            }

        });

        loginButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                loginUser();
            }

        });

        resetPasswordButton.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View view) {
                mDialog.setMessage("Espere un momento...");
                mDialog.setCanceledOnTouchOutside(false);
                mDialog.show();

                Handler handler = new Handler();
                handler.postDelayed(new Runnable() {
                    public void run() {
                        resetPassword();
                    }
                }, 2000);
            }

        });

    }

    /**
     * Method to create a new Account
     */
    public void startCreateAccountActivity(){
        Intent intent = new Intent(this, CreateAccountActivity.class);
        finish();
        startActivity(intent);
        finish();
    }

    /**
     * Method to verify and login the account
     */
    public void loginUser(){
        String email = text_email.getText().toString();
        String password = text_password.getText().toString();
        if(!email.isEmpty() && !password.isEmpty()){
            mAuth.signInWithEmailAndPassword(email, password)
                    .addOnCompleteListener(this, task -> {
                        if (task.isSuccessful()) {
                            getStatsFromFirebaseStore(email);
                            insertAllQuestionToDB();
                            mDialog.setMessage("Espere un momento...");
                            mDialog.setCanceledOnTouchOutside(false);
                            mDialog.show();
                            Handler handler = new Handler();
                            handler.postDelayed(new Runnable() {
                                public void run() {
                                    startMainMenu();
                                }
                            }, 2000);
                        } else {
                            // If sign in fails, display a message to the user.
                            resetPasswordButton.setVisibility(View.VISIBLE);
                            Toast.makeText(this, "Fallo de autenticación",
                                    Toast.LENGTH_SHORT).show();
                        }
                    });
        }else{
            Toast.makeText(this, "Debes escribir una dirección de correo", Toast.LENGTH_SHORT).show();

            text_email.requestFocus();
            InputMethodManager imm = (InputMethodManager) getSystemService(this.INPUT_METHOD_SERVICE);
            imm.showSoftInput(text_email, InputMethodManager.SHOW_IMPLICIT);
        }
    }

    /**
     * Method to send an email to reset the password
     */
    public void resetPassword(){
        if(text_email.getText().toString().isEmpty()){
            Toast.makeText(this, "Se necesita un correo", Toast.LENGTH_SHORT).show();
        }else{
            mAuth.setLanguageCode("es");
            mAuth.sendPasswordResetEmail(text_email.getText().toString()).addOnCompleteListener(new OnCompleteListener<Void>() {
                @Override
                public void onComplete(@NonNull Task<Void> task) {
                    if(task.isSuccessful()){
                        Toast.makeText(LoginActivity.this, "Se ha enviado un correo para restablecer la contraseña", Toast.LENGTH_SHORT).show();
                    }else{
                        Toast.makeText(LoginActivity.this, "Correo no válido", Toast.LENGTH_SHORT).show();
                    }
                }
            });

        }
        mDialog.dismiss();
    }

    /**
     * Method to call the facade to add all question to DB
     */
    public void insertAllQuestionToDB(){
        dbFacade.insertAllQuestionsToDB();
    }

    /**
     * Method to start the mainMenuActivity
     */
    public void startMainMenu(){

        Intent intent = new Intent(this, MainMenuActivity.class);
        finish();
        startActivity(intent);
        finish();
    }

    /**
     * Method to call the facade to get the stats account from Firebase to local
     * @param email
     */
    public void getStatsFromFirebaseStore(String email){
        dbFacade.createUserFromFirebaseStore(email);
    }

    @Override
    protected void onPause() {
        super.onPause();
        //stopService(new Intent(LoginActivity.this,BackgroundSoundService.class));
    }

    @Override
    protected void onResume() {
        super.onResume();
        //startService(new Intent(LoginActivity.this,BackgroundSoundService.class));
    }
}
