package com.example.educode.controller.activity;

import android.content.DialogInterface;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Color;
import android.graphics.Paint;
import android.graphics.Typeface;
import android.graphics.pdf.PdfDocument;
import android.media.MediaPlayer;
import android.os.Bundle;
import android.os.Environment;
import android.util.Log;
import android.view.Gravity;
import android.view.Menu;
import android.view.MenuItem;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;
import java.util.Random;

import androidx.appcompat.app.AlertDialog;
import androidx.appcompat.widget.Toolbar;
import androidx.appcompat.app.AppCompatActivity;
import androidx.core.app.ActivityCompat;
import androidx.core.content.ContextCompat;
import androidx.fragment.app.Fragment;
import androidx.fragment.app.FragmentTransaction;

import com.example.educode.controller.fragment.NameFragment;
import com.example.educode.controller.fragment.RankingFragment;
import com.example.educode.service.BackgroundSoundService;
import com.example.educode.service.BackgroundSoundServiceQuestions;
import com.example.educode.controller.fragment.CertificateFragment;
import com.example.educode.data.DBFacade;
import com.example.educode.R;
import com.example.educode.controller.fragment.AvatarFragment;
import com.example.educode.controller.fragment.EndGameFragment;
import com.example.educode.controller.fragment.FillQuestionFragment;
import com.example.educode.controller.fragment.MenuFragment;
import com.example.educode.controller.fragment.OptionsMenuFragment;
import com.example.educode.controller.fragment.RadioQuestionFragment;
import com.example.educode.model.DateProject;
import com.example.educode.model.FillQuestion;
import com.example.educode.model.Player;
import com.example.educode.model.Question;
import com.example.educode.model.RadioQuestion;

import static android.Manifest.permission.READ_EXTERNAL_STORAGE;
import static android.Manifest.permission.WRITE_EXTERNAL_STORAGE;

public class MainMenuActivity extends AppCompatActivity {

    private MediaPlayer music;
    private TextView textViewFormation;
    private TextView textViewCategoría;
    private TextView textViewPuntos;

    private Fragment menuFragment;
    private Fragment nameFragment;
    private Fragment rankingFragment;
    private Fragment fillQuestionFragment;
    private Fragment radioQuestionFragment;
    private Fragment endGameFragment;
    private Fragment avatarFragment;
    private Fragment certificateFragment;
    private Fragment optionsMenuFragment;
    private FragmentTransaction transaction;
    private final Question[] preChargedLevelQuestions = new Question[50];
    private final Question[] questions = new Question[5];
    private int numQuestionsCharged = 0;
    private int numQuestionsPreCharged = 0;
    private int numQuestionAsked = 0;
    private final int maxQuestionCharged = 5;
    private Question dailyQuestion;
    private int numQuestionCorrect = 0;
    private int dailyFlag = 0;
    private int dailyWin = 0;
    private DBFacade dbFacade = new DBFacade(this);
    private Player player;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main_menu);

       //this.deleteDatabase("db");
        Log.e("TASKROOT", "fuera");
        if(!isTaskRoot()){
            Log.e("TASKROOT", "entra");
            finish();
        }

        if(!session()){
            Log.e("NOBBDD", "Dentro");
            Intent intent = new Intent(this, LoginActivity.class);
            finish();
            startActivity(intent);
            finish();
        }else {
            setToolbar();

            textViewFormation = findViewById(R.id.textView_puntos);
            textViewCategoría = findViewById(R.id.textView_categoria);
            textViewPuntos = findViewById(R.id.textView_puntos);

            getStats();
            updateStatsToFirebase();
            checkDailyQuestionAvailable();
            chargeQuestionsLevel();
            chargeQuestions();

            menuFragment = new MenuFragment();
            getSupportFragmentManager().beginTransaction().add(R.id.fragmentContainerMenu, menuFragment).commit();

            getMenuFragment();
        }
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.toolbar_menu, menu);

        MenuItem resetProfileItem = menu.findItem(R.id.reset_profile);
        resetProfileItem.setOnMenuItemClickListener(new MenuItem.OnMenuItemClickListener() {
            @Override
            public boolean onMenuItemClick(MenuItem menuItem) {
                closeSession();
                return false;
            }
        });

        MenuItem menu_prueba = menu.findItem(R.id.menu_prueba);
        menu_prueba.setOnMenuItemClickListener(new MenuItem.OnMenuItemClickListener() {
            @Override
            public boolean onMenuItemClick(MenuItem menuItem) {
                Log.e("emailBD", dbFacade.getPlayerStringValue(11));
                Log.e("emailPlayer", player.getEmail());
                Log.e("emailDBFacade", dbFacade.getEmail());
                dbFacade.createRankingFromFireStore();
                //Log.e("ranking", dbFacade.getFirstRanking());
                //Log.e("ranking", dbFacade.getSecondRanking());
                return false;
            }
        });


        return true;
    }

    @Override
    protected void onPause() {
        super.onPause();
        if(isMusicAvailable()){
            music = MediaPlayer.create(this, R.raw.pause);
            music.start();
            if(radioQuestionFragment == null){
                stopService(new Intent(MainMenuActivity.this, BackgroundSoundService.class));
            }else{
                stopService(new Intent(MainMenuActivity.this, BackgroundSoundServiceQuestions.class));
            }
        }
    }

    @Override
    protected void onResume() {
        super.onResume();
        if(isMusicAvailable()){
            if(radioQuestionFragment == null){
                startService(new Intent(MainMenuActivity.this,BackgroundSoundService.class));
            }else{
                startService(new Intent(MainMenuActivity.this,BackgroundSoundServiceQuestions.class));
            }
        }

    }

//-------------------------------------------------------------------------------------------------------------------------------------------------------

    /**
     * Method to create the toolbar
     */
    public void setToolbar(){
        Toolbar toolbar = findViewById(R.id.toolbar);
        toolbar.setTitleTextColor(Color.WHITE);
        toolbar.setSubtitleTextColor(Color.WHITE);
        setSupportActionBar(toolbar);
        //getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        getSupportActionBar().setHomeButtonEnabled(true);
        getSupportActionBar().setDisplayShowTitleEnabled(true);
        getSupportActionBar().setIcon(R.mipmap.educode);
        toolbar.inflateMenu(R.menu.toolbar_menu);

    }

    /**
     * Method to close de session and come back to login Activity
     */
    public void closeSession(){
        Toast.makeText(this, "Sesion cerrada", Toast.LENGTH_SHORT).show();
        this.deleteDatabase("db");
        Intent intent = new Intent(this, LoginActivity.class);
        intent.addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
        finish();
        startActivity(intent);
    }

    /**
     * Method to add points to the player
     * @param points points added
     */
    public void addPoints(int points){
        player.setPoints(player.getPoints()+points);
        SoundCoin();
        toastPoints(points);
        updatePoints();
        addQuestionCorret();
        if(player.getCategory().checkCategory(player.getPoints(), this)){
            SoundCategory();
            toastCategory();
            textViewCategoría.setText(player.getCategoryName());
        }
    }

    /**
     * Method to create the sound when the player wins points
     */
    public void SoundCoin(){
        music = MediaPlayer.create(this, R.raw.up);
        music.start();
    }

    /**
     * Method to create the sound when the player level up
     */
    public void SoundCategory(){
        music = MediaPlayer.create(this, R.raw.category);
        music.start();
    }

    /**
     * Method to create a sound when the player fails a question
     */
    public void SoundWrong(){
        music = MediaPlayer.create(this, R.raw.wrong);
        music.start();
    }

    /**
     * Method to get all parameters from database to classes
     */
    public void getStats(){
        int[] intAux;
        intAux = dbFacade.getIntStats();
        String[] stringAux;
        stringAux = dbFacade.getStringStats();

        player = new Player(1, stringAux[0], intAux[0], stringAux[2], stringAux[3], stringAux[4], intAux[1], intAux[2], intAux[3], intAux[4], intAux[5], stringAux[5]);

        textViewFormation.setText(player.getFormation());
        textViewCategoría.setText(player.getCategoryName());
        textViewPuntos.setText("Puntos: " + player.getPointsToString());

    }

    /**
     * Method to update points
     */
    public void updatePoints(){
        dbFacade.updatePlayerValue("puntos", player.getPoints());
        textViewPuntos.setText("Puntos: " + player.getPointsToString());
    }

    /**
     * Method to get the player points
     * @return current points
     */
    public int getPlayerPoints(){
        return player.getPoints();
    }

    /**
     * Method to create a toast when level up
     */
    public void toastCategory(){
        Toast toast = new Toast(this);
        ImageView view = new ImageView(this);
        view.setImageResource(R.drawable.level_up);

        float y = textViewCategoría.getY();

        toast.setGravity(Gravity.TOP|Gravity.RIGHT, 0, (int)y-(int)y/10);
        toast.setView(view);
        toast.show();
    }

    /**
     * Method to create a toast when the player add points
     * @param i points num
     */
    public void toastPoints(int i){
        Toast toast = new Toast(this);
        ImageView view = new ImageView(this);
        if (i == 50){
            view.setImageResource(R.drawable.cincuenta);
        }else if(i == 100){
            view.setImageResource(R.drawable.cien);
        }else if(i == 200){
            view.setImageResource(R.drawable.doscientos);
        }

        float y = textViewPuntos.getY();

        toast.setGravity(Gravity.TOP|Gravity.LEFT, 0, (int)y-(int)y/4);
        toast.setView(view);
        toast.show();
    }

    /**
     * Method to start to play
     */
    public void play(){
        music = MediaPlayer.create(this, R.raw.startgame2);
        music.start();

        if(isMusicAvailable()){
            stopService(new Intent(MainMenuActivity.this,BackgroundSoundService.class));
            startService(new Intent(MainMenuActivity.this,BackgroundSoundServiceQuestions.class));
        }

        if(questions[numQuestionAsked].getClass().equals(RadioQuestion.class)){
            radioQuestionFragment = new RadioQuestionFragment();
            transaction = getSupportFragmentManager().beginTransaction();
            transaction.replace(R.id.fragmentContainerMenu, radioQuestionFragment).commit();
        }else{
            fillQuestionFragment = new FillQuestionFragment();
            transaction = getSupportFragmentManager().beginTransaction();
            transaction.replace(R.id.fragmentContainerMenu, fillQuestionFragment).commit();
        }


    }

    /**
     * Method to exit the application
     */
    public void exitApplication(){
        stopService(new Intent(MainMenuActivity.this,BackgroundSoundService.class));
        finish();
        System.exit(0);
    }

    /**
     * Methods to create two arrays with player level questions
     */
    public  void chargeQuestionsLevel(){
       chargedLevelRadioQuestions();
       chargedLevelFillQuestions();
    }

    public void chargeQuestions(){
        int min = 0;
        int max = numQuestionsPreCharged-1;
        int random = 0;
        int[] questionAdded = new int[5];

        while (numQuestionsCharged < maxQuestionCharged) {
            boolean newQuestionID = false;

            while(!newQuestionID) {
                newQuestionID = true;
                random = new Random().nextInt((max - min) + 1) + min;
                for (int i = 0; i < numQuestionsCharged; i ++) {
                    if(questionAdded[i] == random) {
                        newQuestionID = false;
                    }
                }
            }
            questionAdded[numQuestionsCharged] = random;
            if(preChargedLevelQuestions[random].getClass().equals(RadioQuestion.class)){
                questions[numQuestionsCharged] = (RadioQuestion) preChargedLevelQuestions[random];
            }else{
                questions[numQuestionsCharged] = (FillQuestion) preChargedLevelQuestions[random];
            }
            numQuestionsCharged++;
        }
    }

    public Question getQuestion(){
        return questions[numQuestionAsked];
    }

    /**
     * Method to go to the next question
     */
    public void nextQuestion(){
        numQuestionAsked++;
        if(checkEndGame()){
            stopService(new Intent(MainMenuActivity.this,BackgroundSoundServiceQuestions.class));
            if(isMusicAvailable()){
                if(checkWin()){
                    music = MediaPlayer.create(this, R.raw.win);
                    music.start();
                }else{
                    music = MediaPlayer.create(this, R.raw.game_over);
                    music.start();
                }
            }
            endGameFragment = new EndGameFragment();
            transaction = getSupportFragmentManager().beginTransaction();
            transaction.replace(R.id.fragmentContainerMenu, endGameFragment).commit();

        }else {
            if(questions[numQuestionAsked].getClass().equals(RadioQuestion.class)){
                radioQuestionFragment = new RadioQuestionFragment();
                transaction = getSupportFragmentManager().beginTransaction();
                transaction.replace(R.id.fragmentContainerMenu, radioQuestionFragment).commit();
            }else{
                fillQuestionFragment = new FillQuestionFragment();
                transaction = getSupportFragmentManager().beginTransaction();
                transaction.replace(R.id.fragmentContainerMenu, fillQuestionFragment).commit();
            }


        }
    }

    /**
     * Get the main manu fragment
     */
    public void getMenuFragment(){
        menuFragment = new MenuFragment();
        transaction = getSupportFragmentManager().beginTransaction();
        transaction.replace(R.id.fragmentContainerMenu, menuFragment).commit();
    }

    /**
     * Get the avatar fragment
     */
    public void getAvatarFragment(){
        avatarFragment = new AvatarFragment();
        transaction = getSupportFragmentManager().beginTransaction();
        transaction.replace(R.id.fragmentContainerMenu, avatarFragment).commit();
    }

    /**
     * Get the certificate fragment
     */
    public void getCertificateFragment(){
        certificateFragment = new CertificateFragment();
        transaction = getSupportFragmentManager().beginTransaction();
        transaction.replace(R.id.fragmentContainerMenu, certificateFragment).commit();
    }

    /**
     * Get the name fragment
     */
    public void getNameFragment(){
        nameFragment = new NameFragment();
        transaction = getSupportFragmentManager().beginTransaction();
        transaction.replace(R.id.fragmentContainerMenu, nameFragment).commit();
    }

    /**
     * get the ranking fragment
     */
    public void getRankingFragment(){
        rankingFragment = new RankingFragment();
        transaction = getSupportFragmentManager().beginTransaction();
        transaction.replace(R.id.fragmentContainerMenu, rankingFragment).commit();
    }

    /**
     * get the options fragment
     */
    public void getOptionsMenuFragment(){
        menuFragment = new OptionsMenuFragment();
        transaction = getSupportFragmentManager().beginTransaction();
        transaction.replace(R.id.fragmentContainerMenu, menuFragment).commit();
    }

    public void getMenuOptionsFragmentTransaction(){
        optionsMenuFragment = new OptionsMenuFragment();
        transaction = getSupportFragmentManager().beginTransaction();
        transaction.replace(R.id.fragmentContainerMenu, optionsMenuFragment).commit();
    }

    /**
     * Add question correct to the variable for this game
     */
    public void addQuestionCorret(){
        numQuestionCorrect++;
    }

    /**
     * Method to restart the mainActivity
     */
    public void restartActivity(){
        Intent intent = getIntent();
        intent.addFlags(Intent.FLAG_ACTIVITY_CLEAR_TOP);
        finish();
        startActivity(intent);
    }

    public String getPlayername(){
        return player.getName();
    }

    public int getMaxQuestionCharged(){
        return maxQuestionCharged;
    }
    public int getNumQuestionCorrect(){
        return numQuestionCorrect;
    }

    /**
     * Method to check if this round the player win
     * @return true if win or false if lost
     */
    public boolean checkWin(){
        float aprobado = getMaxQuestionCharged()/2;
        if(numQuestionCorrect > aprobado){
            return true;
        }
        return false;
    }

    /**
     * Check if the questions was the last question
     * @return true if was the last question and false if not
     */
    public boolean checkEndGame(){
        if(questions.length == numQuestionAsked){
            return true;
        }
        return false;
    }

    /**
     * Check if this round the player hit all questions
     * @return true if hit all and false if not
     */
    public boolean checkAllCorrect(){
        if(numQuestionCorrect == getMaxQuestionCharged()){
            return true;
        }
        return false;
    }

    /**
     * Check if the player fails all questions in this round
     * @return true if fails all questions and false if not
     */
    public boolean checkAllWrong(){
        if(numQuestionCorrect == 0){
            return true;
        }
        return false;
    }
    public void setAvatarImage(String image){
        dbFacade.updatePlayerValue("avatar", image);
    }

    public String getAvatarString(){
        return player.getAvatar();
    }
    public boolean isMusicAvailable(){
        if (player.getMusic() == 1){
            return true;
        }else{
            return false;
        }
    }

    public void setMusicAvailable(int i){
        dbFacade.updatePlayerValue("music", i);
    }

    public void setName(String name){
        dbFacade.updatePlayerValue("nombre", name);
    }

    public void chargedLevelRadioQuestions(){
        Question[] aux = dbFacade.getAllRadioQuestionsPerLevel(player.getCategoryName());
        int index = 0;
        while(aux[index] != null) {
            preChargedLevelQuestions[numQuestionsPreCharged] = aux[index];
            numQuestionsPreCharged++;
            index++;
        }

    }

    public void chargedLevelFillQuestions(){
        Question[] aux = dbFacade.getAllFillQuestionsPerLevel(player.getCategoryName());
        int index = 0;
        while(aux[index] != null) {
            preChargedLevelQuestions[numQuestionsPreCharged] = aux[index];
            numQuestionsPreCharged++;
            index++;
        }
    }

    public String getCategoryName(){
        return player.getCategoryName();
    }

    /**
     * Method to create a certificate pdf
     * @param fullname Full name of player
     * @param dni DNI or NIE of player
     */
    public void generatePDF(String fullname, String dni) {
        if (checkPermission()) {
            //Toast.makeText(this, "Permission Granted", Toast.LENGTH_SHORT).show();
        } else {
            requestPermission();
        }

        DateProject currentDate = new DateProject();
        int pageHeight = 792;
        int pagewidth = 1120;
        Bitmap bmp, scaledbmp;
        bmp = BitmapFactory.decodeResource(getResources(), R.drawable.downloadcertificate);
        scaledbmp = Bitmap.createScaledBitmap(bmp, pagewidth, pageHeight, false);
        PdfDocument pdfDocument = new PdfDocument();
        Paint paint = new Paint();
        Paint title = new Paint();
        PdfDocument.PageInfo mypageInfo = new PdfDocument.PageInfo.Builder(pagewidth, pageHeight, 1).create();
        PdfDocument.Page myPage = pdfDocument.startPage(mypageInfo);
        Canvas canvas = myPage.getCanvas();
        canvas.drawBitmap(scaledbmp, 0, 0, paint);
        title.setTypeface(Typeface.create(Typeface.DEFAULT, Typeface.NORMAL));
        title.setTextSize(32);
        title.setColor(ContextCompat.getColor(this, R.color.colorPrimaryDark));
        canvas.drawText(fullname + " - " + dni, 324, 300, title);
        title.setTypeface(Typeface.defaultFromStyle(Typeface.NORMAL));
        title.setColor(ContextCompat.getColor(this, R.color.colorPrimaryDark));
        title.setTextSize(32);
        title.setTextAlign(Paint.Align.CENTER);
        canvas.drawText(player.getCategoryName(), 463, 465, title);
        canvas.drawText(currentDate.getPatternDate(), 423, 620, title);
        pdfDocument.finishPage(myPage);
        File file = new File(Environment.getExternalStorageDirectory() + "/Download/", "certificado_" + player.getCategoryName() + ".pdf");

        try {
            pdfDocument.writeTo(new FileOutputStream(file));
            Toast.makeText(this, "Se ha descargado el certificado en la carpeta 'Download'", Toast.LENGTH_SHORT).show();
        } catch (IOException e) {
            e.printStackTrace();
        }

        pdfDocument.close();
    }

    private boolean checkPermission() {
        int permission1 = ContextCompat.checkSelfPermission(getApplicationContext(), WRITE_EXTERNAL_STORAGE);
        int permission2 = ContextCompat.checkSelfPermission(getApplicationContext(), READ_EXTERNAL_STORAGE);
        return permission1 == PackageManager.PERMISSION_GRANTED && permission2 == PackageManager.PERMISSION_GRANTED;
    }

    private void requestPermission() {
        ActivityCompat.requestPermissions(this, new String[]{WRITE_EXTERNAL_STORAGE, READ_EXTERNAL_STORAGE}, 200);
    }

    public void toastNeedCertificateName(){
        Toast.makeText(this, "Debes escribir un nombre y un DNI", Toast.LENGTH_SHORT).show();
    }

    public void setDailyDb(int i){
        dbFacade.updatePlayerValue("daily", i);
    }

    public boolean isDailyAvailable(){
      return player.isDailyAvailable();
    }

    public Question getDailyQuestion(){
        return dailyQuestion;
    }

    /**
     * Method to start the daily question
     */
    public void startDailyQuestion(){
        setDailyDb(0);
        setDailyDate();
        int min = 0;
        int max = numQuestionsPreCharged-1;
        int random = 0;
        random = new Random().nextInt((max - min) + 1) + min;
        dailyFlag = 1;


        music = MediaPlayer.create(this, R.raw.startgame2);
        music.start();

        if(isMusicAvailable()){
            stopService(new Intent(MainMenuActivity.this,BackgroundSoundService.class));
            startService(new Intent(MainMenuActivity.this,BackgroundSoundServiceQuestions.class));
        }

        dailyQuestion = preChargedLevelQuestions[random];

        if(preChargedLevelQuestions[random].getClass().equals(RadioQuestion.class)){
            radioQuestionFragment = new RadioQuestionFragment();
            transaction = getSupportFragmentManager().beginTransaction();
            transaction.replace(R.id.fragmentContainerMenu, radioQuestionFragment).commit();
        }else{
            fillQuestionFragment = new FillQuestionFragment();
            transaction = getSupportFragmentManager().beginTransaction();
            transaction.replace(R.id.fragmentContainerMenu, fillQuestionFragment).commit();
        }
    }

    public int getdailyFlag(){
        return dailyFlag;
    }

    public void endDailyQuestion(){
        if(isMusicAvailable()) {
            stopService(new Intent(MainMenuActivity.this, BackgroundSoundServiceQuestions.class));
        }
        endGameFragment = new EndGameFragment();
        transaction = getSupportFragmentManager().beginTransaction();
        transaction.replace(R.id.fragmentContainerMenu, endGameFragment).commit();

    }

    public void checkDailyQuestionAvailable(){
        if(player.checkDailyQuestionAvailable()){
            setDailyDb(1);
        }
    }
    public void setDailyDate(){
        DateProject currentDate = new DateProject();
        dbFacade.updatePlayerValue("dailyday", currentDate.getDay());
        dbFacade.updatePlayerValue("dailymonth", currentDate.getMonth());
        dbFacade.updatePlayerValue("dailyyear", currentDate.getYear());
    }

    public void setDailyWin(int i){
        dailyWin = i;
    }

    public int getDailyWin(){
        return dailyWin;
    }

    /**
     * Check if the player is logged in the aplication
     * @return true if the player is logged or false if not
     */
    public boolean session() {
        if (dbFacade.getPlayerStringValue(11).isEmpty()) {
            return false;
        }else{
            return true;
        }
    }

    public void getRanking(){
        dbFacade.createRankingFromFireStore();
    }

    /**
     * Method to synchronize the local db to firebase
     */
    public void updateStatsToFirebase(){
        dbFacade.updatePlayerValueToFirebase("avatar", player.getAvatar());
        dbFacade.updatePlayerValueToFirebase("categoria", player.getCategoryName());
        dbFacade.updatePlayerValueToFirebase("daily", player.getDaily());
        dbFacade.updatePlayerValueToFirebase("formacion", player.getFormation());
        dbFacade.updatePlayerValueToFirebase("music", player.getMusic());
        dbFacade.updatePlayerValueToFirebase("nombre", player.getName());
        dbFacade.updatePlayerValueToFirebase("puntos", player.getPoints());
        dbFacade.updatePlayerValueToFirebase("dailyday", dbFacade.getPlayerStringValue(8));
        dbFacade.updatePlayerValueToFirebase("dailymonth", dbFacade.getPlayerStringValue(9));
        dbFacade.updatePlayerValueToFirebase("dailyyear", dbFacade.getPlayerStringValue(10));
    }

    public String[] getPlayerRankingByPostion(int i){
        return dbFacade.getPlayerRankingByPosition(i);
    }

}
